@@ -60,21 +60,11 @@ def enter_and_leave_function(func: Callable) -> Callable:
         try:
             result = func(*args, **kwargs)
             if isinstance(result, ExecResult):
-                if result.exit_status_code == 0:
-                    log.info(
-                        f"[{func_def_file}: {func_def_line}]"
-                        f" finish run function {func.__name__}(), stdout is: {result.stdout} "
-                    )
-                else:
+                if result.exit_status_code != 0:
                     log.warning(
                         f"[{func_def_file}: {func_def_line}]"
                         f" failed to run function {func.__name__}(), stderr is: {result.stderr} "
                     )
-            else:
-                log.info(
-                    f"[{func_def_file}: {func_def_line}]"
-                    f" finish run function {func.__name__}(), return value is: {result} "
-                )
             return result
 
         except Exception as e:
@@ -193,13 +183,12 @@ class SSHClient(object):
 
     @enter_and_leave_function
     def _exec(self, cmd, promt_response,timeout=60):
-        log.info(f" {self.__ip}:{self.__port} | begin to run cmd:{cmd}.")
         try:
             transport = self.__ssh.get_transport()
             if not transport or not transport.is_active():
+                log.warning(f"{self.__ip}:{self.__port} | ssh connection is not active.")
                 return ExecResult(1, "", "SSH连接已关闭或不可用")
 
-
             if promt_response:
                 channel = transport.open_session()
                 # 设置终端尺寸
@@ -254,12 +243,6 @@ class SSHClient(object):
                 exit_status = stdout.channel.recv_exit_status()
                 std_output = stdout.read().decode()
                 std_err = stderr.read().decode()
-                if not std_err:
-                    log.info(
-                        f" {self.__ip}:{self.__port} | successful to run cmd {cmd}, exit_status_code is {exit_status}, output is:{std_output} and stderr:{std_err}.")
-                else:
-                    log.info(
-                    f" {self.__ip}:{self.__port} | successful to run cmd {cmd}, exit_status_code is {exit_status}, output is:{std_output}.")
                 return ExecResult(exit_status, std_output, std_err)
         except Exception as e:
             return ExecResult(1, "", str(e))
@@ -293,7 +276,6 @@ class SSHClient(object):
                 return False
 
             # 上传文件
-            log.info(f" {self.__ip}:{self.__port} | 拷贝文件: {local_path} -> {remote_path}")
             try:
                 self.__sftp.put(str(local_path), str(remote_path))
             except Exception as e:
@@ -331,20 +313,18 @@ class SSHClient(object):
                     remote_file_parent = remote_file.parent
                     rs=self.exec(f"ls {remote_file_parent}")
                     if rs.exit_status_code != 0:
-                        log.info(f" {self.__ip}:{self.__port} | 创建目录: {remote_file_parent}")
-                        self.exec(f"mkdir -p {remote_file_parent}")
-                    else:
-                        log.info(f" {self.__ip}:{self.__port} | 目录已存在: {remote_file_parent}")
+                        rs=self.exec(f"mkdir -p {remote_file_parent}")
+                        if rs.exit_status_code != 0:
+                            log.error(f" {self.__ip}:{self.__port} | 创建目录失败: {remote_file_parent}")
+                            return False
                     # 上传文件
                     try:
                         self.__sftp.put(str(local_file), str(remote_file))
-                        log.info(f" {self.__ip}:{self.__port} | 已拷贝: {local_file} -> {remote_file}")
                     except Exception as e:
                         log.error(
                             f" {self.__ip}:{self.__port} | 拷贝失败: {local_file} -> {remote_file}, 错误: {str(e)}")
                         return False
 
-            log.info(f" {self.__ip}:{self.__port} | 文件夹拷贝完成: {local_path} -> {remote_path}")
             return True
 
         # 本地路径无效
@@ -380,16 +360,11 @@ class SSHClient(object):
 
     @enter_and_leave_function
     def _scp_file_to_local(self, remote_path, local_path):
-        log.info(
-            f" {self.__ip}:{self.__port} | Begin to copy file from remote {remote_path} to local host {local_path}.")
         if os.path.isfile(local_path):
             subprocess.run(['rm', '-rf', local_path], capture_output=True, text=True)
         for i in range(3):
-            log.info(f" {self.__ip}:{self.__port} | Try to copy file from remote {remote_path} to local host{local_path}, retry {i}.")
             try:
                 self.__sftp.get(remote_path, local_path)
-                log.info(
-                    f" {self.__ip}:{self.__port} | Success to copy file from remote {remote_path} to local host{local_path}:OK.")
                 return True
             except OSError as e:
                 log.warning(
